@@ -82,7 +82,17 @@ gint timeout_left;
 gchar *
 ldm_theme_file(char * file)
 {
-    return g_strconcat(ldm_theme_dir, file, NULL);
+    gchar * filename;
+    filename = g_strconcat("/", ldm_theme_dir, "/", file, NULL);
+    if (access(g_strconcat(filename, ".png", NULL), F_OK ) != -1)
+    {
+        filename = g_strconcat(filename, ".png", NULL);
+    }
+    else if (access(g_strconcat(filename, ".jpg", NULL), F_OK ) != -1)
+    {
+        filename = g_strconcat(filename, ".jpg", NULL);
+    }
+    return filename;
 }
 
 static void
@@ -309,26 +319,26 @@ popup_menu(GtkWidget * widget, GtkWindow * window)
 
     lang_item =
         gtk_image_menu_item_new_with_mnemonic(_("Select _Language ..."));
-    langico = gtk_image_new_from_file(ldm_theme_file("/language.png"));
+    langico = gtk_image_new_from_file(ldm_theme_file("language"));
     gtk_image_menu_item_set_image((GtkImageMenuItem *) lang_item, langico);
 
     sess_item =
         gtk_image_menu_item_new_with_mnemonic(_("Select _Session ..."));
-    sessico = gtk_image_new_from_file(ldm_theme_file("/session.png"));
+    sessico = gtk_image_new_from_file(ldm_theme_file("session"));
     gtk_image_menu_item_set_image((GtkImageMenuItem *) sess_item, sessico);
 
     host_item =
         gtk_image_menu_item_new_with_mnemonic(_("Select _Host ..."));
-    hostico = gtk_image_new_from_file(ldm_theme_file("/host.png"));
+    hostico = gtk_image_new_from_file(ldm_theme_file("host"));
     gtk_image_menu_item_set_image((GtkImageMenuItem *) host_item, hostico);
 
     sep = gtk_separator_menu_item_new();
     reboot_item = gtk_image_menu_item_new_with_mnemonic(_("_Reboot"));
-    rebootico = gtk_image_new_from_file(ldm_theme_file("/reboot.png"));
+    rebootico = gtk_image_new_from_file(ldm_theme_file("reboot"));
     gtk_image_menu_item_set_image((GtkImageMenuItem *) reboot_item,
                                   rebootico);
     quit_item = gtk_image_menu_item_new_with_mnemonic(_("Shut_down"));
-    haltico = gtk_image_new_from_file(ldm_theme_file("/shutdown.png"));
+    haltico = gtk_image_new_from_file(ldm_theme_file("shutdown"));
     gtk_image_menu_item_set_image((GtkImageMenuItem *) quit_item, haltico);
 
     g_signal_connect_swapped(G_OBJECT(quit_item), "activate",
@@ -467,10 +477,10 @@ main(int argc, char *argv[])
     w = width;
     h = height;
 
-    logo = gtk_image_new_from_file(ldm_theme_file("/logo.png"));
+    logo = gtk_image_new_from_file(ldm_theme_file("logo"));
 #ifdef K12LINUX
-    if(access(ldm_theme_file("/bottom_right.png"), R_OK) == 0) {
-        bottom_right = gtk_image_new_from_file(ldm_theme_file("/bottom_right.png"));
+    if(access(ldm_theme_file("bottom_right"), R_OK) == 0) {
+        bottom_right = gtk_image_new_from_file(ldm_theme_file("bottom_right"));
         has_bottom_right_image=TRUE;
     }
     else
@@ -483,7 +493,7 @@ main(int argc, char *argv[])
 
     spheight = (height / 4) - (lh / 2);
 
-    rawpic = gdk_pixbuf_new_from_file_at_scale(ldm_theme_file("/bg.png"),
+    rawpic = gdk_pixbuf_new_from_file_at_scale(ldm_theme_file("bg"),
                                                pw, ph, FALSE, NULL);
     gdk_pixbuf_render_pixmap_and_mask(rawpic, &pic, &mask, 0);
     gdk_pixbuf_unref(rawpic);
