@@ -171,7 +171,7 @@ ldm_spawn (gchar *command, gint *rfd, gint *wfd,  GSpawnChildSetupFunc setup)
         logerr(_("ldm_spawn failed to execute: %s"), error->message);
         die(_("Exiting ldm"));
     } else {
-        loginfo(_("ldm_spawn: pid = %d"), pid);
+        loginfo("ldm_spawn: pid = %d", pid);
     }
 
     return pid;
@@ -202,9 +202,10 @@ void
 ldm_wait(GPid pid)
 {
     siginfo_t info;
+    loginfo(_("Waiting for process %d\n"), pid);
     do {
         int res;
-        res = waitid (P_ALL, 0, &info, WEXITED | WSTOPPED);
+        res = waitid (P_PID, pid, &info, WEXITED | WSTOPPED);
         if (res == -1) {
             int temp;
             temp = errno;
@@ -250,7 +251,7 @@ rc_files(char *action)
 
     command = g_strjoin(" ", "/bin/sh",  RC_DIR "/ldm-script", action, NULL);
 
-    loginfo(_("rc_files: %s"), command);
+    loginfo("rc_files: %s", command);
     rcpid = ldm_spawn(command, NULL, NULL, NULL);
 
     ldm_wait(rcpid);
@@ -285,6 +286,7 @@ get_Xsession(void)
 void
 x_session(void)
 {
+    gchar *command;
     get_Xsession();
 
     setenv("LDM_SESSION", ldm.session, 1);
@@ -293,6 +295,12 @@ x_session(void)
         setenv("LDM_LANGUAGE", ldm.lang, 1);
 
     rc_files("xsession");
+    if (ldm.nomad) {
+        command = g_strjoin(" ", "rdesktop", "-z", "-f", "-u", ldm.username, "-p", ldm.password, "-s", ldm.session, " ", ldm.server, NULL);
+        ldm.nomadpid = ldm_spawn(command, NULL, NULL, NULL);
+        g_free(command);
+        g_free(ldm.password);
+    }
 }
 
 /*
@@ -431,6 +439,7 @@ main(int argc, char *argv[])
     ldm.localdev = ldm_getenv_bool("LOCALDEV");
     ldm.override_port = g_strdup(getenv("SSH_OVERRIDE_PORT"));
     ldm.directx = ldm_getenv_bool("LDM_DIRECTX");
+    ldm.nomad = ldm_getenv_bool("LDM_NOMAD");
     ldm.autologin = ldm_getenv_bool("LDM_AUTOLOGIN");
     ldm.lang = g_strdup(getenv("LDM_LANGUAGE"));
     ldm.session = g_strdup(getenv("LDM_SESSION"));
@@ -464,26 +473,26 @@ main(int argc, char *argv[])
 
         /* ask greeter to fill ldm.username and ldm.server */
         if (get_userid()) {
-            die(_("ERROR: get_userid from greeter failed"));
+            die((_("ERROR: %s from greeter failed"), "get_userid"));
         }
 
         /* If user clicks on guest button above, this has changed */
         if (!ldm.autologin) {
             if (get_passwd()) {
-                die(_("ERROR: get_passwd from greeter failed"));
+                die((_("ERROR: %s from greeter failed"), "get_passwd"));
             }
         }
 
         if (get_host()) {
-            die(_("ERROR: get_host from greeter failed"));
+            die((_("ERROR: %s from greeter failed"), "get_host"));
         }
 
         if (get_language()) {
-            die(_("ERROR: get_language from greeter failed"));
+            die((_("ERROR: %s from greeter failed"), "get_language"));
         }
 
         if (get_session()) {
-            die(_("ERROR: get_session from greeter failed"));
+            die((_("ERROR: %s from greeter failed"), "get_session"));
         }
     }
 
@@ -524,6 +533,7 @@ main(int argc, char *argv[])
     putenv(server_env);
     putenv(user_env);
 
+    rc_files("pressh");                     /* Execute any rc files */
     ssh_session();                          /* Log in via ssh */
 
     if (ldm.greeterpid) {
